﻿using System;
using System.Windows;

using DevExpress.Xpf.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field 
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 샘플 리스트
        /// </summary>
        private SampleList sampleList = new SampleList();

        /// <summary>
        /// 선택 도우미
        /// </summary>
        private SelectionHelper<Guid> selectionHelper = new SelectionHelper<Guid>();

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor 
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 메인 윈도우 - MainWindow()

        /// <summary>
        /// 메인 윈도우
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            DataContext = this.sampleList;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method 
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 컨트롤 커스텀 언바운드 컬럼 데이터 처리하기 - gridControl_CustomUnboundColumnData(sender, e)

        /// <summary>
        /// 그리드 컨트롤 커스텀 언바운드 컬럼 데이터 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridControl_CustomUnboundColumnData(object sender, GridColumnDataEventArgs e)
        {
            if(e.Column.FieldName != "Selected")
            {
                return;
            }

            Guid keyGuid = (Guid)e.GetListSourceFieldValue("ID");

            if(e.IsGetData)
            {
                e.Value = this.selectionHelper.GetIsSelected(keyGuid);
            }

            if(e.IsSetData)
            {
                this.selectionHelper.SetIsSelected(keyGuid, (bool)e.Value);
            }
        }

        #endregion
        #region Invert Selection 버튼 클릭시 처리하기 - invertSelectionButton_Click(sender, e)

        /// <summary>
        /// Invert Selection 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void invertSelectionButton_Click(object sender, RoutedEventArgs e)
        {
            for(int i = 0; i < this.sampleList.Data.Count; i++)
            {
                int rowHandle = this.gridControl.GetRowHandleByListIndex(i);

                bool newIsSelected = !this.selectionHelper.GetIsSelected(this.sampleList.Data[i].ID);

                this.gridControl.SetCellValue(rowHandle, "Selected", newIsSelected);
            }
        }

        #endregion
        #region Get Selection 버튼 클릭시 처리하기 - getSelectionButton_Click(sender, e)

        /// <summary>
        /// Get Selection 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void getSelectionButton_Click(object sender, RoutedEventArgs e)
        {
            string caption = string.Format("Selected rows (Total: {0})", this.selectionHelper.GetSelectionCount());

            MessageBox.Show(this.selectionHelper.GetStringFromSelectedKeyList(), caption);
        }

        #endregion
    }
}