﻿using System.Collections.Generic;
using System.Text;

namespace TestProject
{
    /// <summary>
    /// 선택 도우미
    /// </summary>
    /// <typeparam name="KeyType">키 타입</typeparam>
    public class SelectionHelper<KeyType>
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 사전
        /// </summary>
        private Dictionary<KeyType, bool> dictionary = new Dictionary<KeyType, bool>();

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 선택 여부 구하기 - GetIsSelected(key)

        /// <summary>
        /// 선택 여부 구하기
        /// </summary>
        /// <param name="key">키</param>
        /// <returns>선택 여부</returns>
        public bool GetIsSelected(KeyType key)
        {
            bool isSelected;

            if(this.dictionary.TryGetValue(key, out isSelected))
            {
                return isSelected;
            }

            return false;
        }

        #endregion
        #region 선택 여부 설정하기 - SetIsSelected(key, value)

        /// <summary>
        /// 선택 여부 설정하기
        /// </summary>
        /// <param name="key">키</param>
        /// <param name="value">값</param>
        public void SetIsSelected(KeyType key, bool value)
        {
            if(value)
            {
                this.dictionary[key] = value;
            }
            else
            {
                this.dictionary.Remove(key);
            }
        }

        #endregion
        #region 선택 키 리스트 구하기 - GetSelectedKeyList()

        /// <summary>
        /// 선택 키 리스트 구하기
        /// </summary>
        /// <returns>선택 키 리스트</returns>
        public List<KeyType> GetSelectedKeyList()
        {
            List<KeyType> keyList = new List<KeyType>();

            foreach(KeyType key in this.dictionary.Keys) 
            {
                keyList.Add(key);
            }

            return keyList;
        }

        #endregion
        #region 선택 키 리스트에서 문자열 구하기 - GetStringFromSelectedKeyList()

        /// <summary>
        /// 선택 키 리스트에서 문자열 구하기
        /// </summary>
        /// <returns>문자열</returns>
        public string GetStringFromSelectedKeyList()
        {
            List<KeyType> keyList = GetSelectedKeyList();

            StringBuilder stringBuilder = new StringBuilder();

            for(int i = 0; i < keyList.Count; i++)
            {
                stringBuilder.AppendLine(keyList[i].ToString());
            }

            return stringBuilder.ToString();
        }

        #endregion
        #region 선택 카운트 구하기 - GetSelectionCount()

        /// <summary>
        /// 선택 카운트 구하기
        /// </summary>
        /// <returns>선택 카운트</returns>
        public int GetSelectionCount()
        {
            return this.dictionary.Count;
        }

        #endregion
    }
}